analphipy.PhiCut
================

.. currentmodule:: analphipy

.. autoclass:: PhiCut

   
   ..
      .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree:
   
      ~PhiCut.__init__
      ~PhiCut.asdict
      ~PhiCut.assign
      ~PhiCut.assign_min_numeric
      ~PhiCut.dphidr
      ~PhiCut.minimize
      ~PhiCut.new_like
      ~PhiCut.phi
      ~PhiCut.to_measures
      ~PhiCut.to_nf
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree:
   
      ~PhiCut.phi_base
      ~PhiCut.phi_min
      ~PhiCut.r_min
      ~PhiCut.rcut
      ~PhiCut.segments
   
   

   
   
   .. rubric:: Dunder Methods

   .. autosummary::
      :toctree:
   
      ~PhiCut.__repr__
   
   